Crate expiring_ref

Crate expiring_ref 

Modules

iter
macros
traits
unstable

Macros

deconstruct
Basic macro for field projection

Structs

DerefOwnGuard
Own
&'a own T, aka an equivalent to C++’s T&& More specifically, this value represents an owned reference which has its contents dropped when it itself is dropped.