Crate expiring_ref
expiring_
ref
0.7.3
All Items
Crate Items
Modules
Structs
Crate
expiring_
ref
Modules

iter
macros
traits
unstable
Structs

Deref
OwnGuard
Own
&'a own T
, aka an equivalent to C++’s
T&&
More specifically, this value represents an owned reference which has its contents dropped when it itself is dropped.